Documentation
¶
Index ¶
- func CustomLogMiddleware(logger logevent.Logger) func(http.Handler) http.Handler
- func CustomStatMiddleware(stats xstats.XStater, tags ...string) func(http.Handler) http.Handler
- func DefaultLogMiddleware() func(http.Handler) http.Handler
- func DefaultStatMiddleware(tags ...string) func(http.Handler) http.Handler
- func NopLogMiddleware() func(http.Handler) http.Handler
- func NopStatMiddleware(tags ...string) func(http.Handler) http.Handler
- func OS() chan error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CustomLogMiddleware ¶
CustomLogMiddleware injects the provided logger in each incoming request's context
func CustomStatMiddleware ¶
CustomStatMiddleware injects the provided stats client in each incoming request's context
func DefaultLogMiddleware ¶
DefaultLogMiddleware injects the default logger on each incoming request's context
func DefaultStatMiddleware ¶
DefaultStatMiddleware injects the default stats client on each incoming request's context
func NopLogMiddleware ¶
NopLogMiddleware injects a nop logger in each incoming request's context
func NopStatMiddleware ¶
NopStatMiddleware injects a nop stats client in each incoming request's context
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.